==> com.seafile.seadroid2_180_src.tar.gz: com.seafile.seadroid2_180_src.tar.gz/app/src/main/java/com/seafile/seadroid2/ui/transfer_list/DownloadListFragment.java <==
package com.seafile.seadroid2.ui.transfer_list;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;

import com.seafile.seadroid2.bus.BusHelper;
import com.seafile.seadroid2.enums.TransferAction;
import com.seafile.seadroid2.enums.TransferDataSource;
import com.seafile.seadroid2.framework.worker.queue.TransferModel;
import com.seafile.seadroid2.framework.util.SLogs;
import com.seafile.seadroid2.framework.worker.TransferEvent;
import com.seafile.seadroid2.framework.worker.TransferWorker;
import com.seafile.seadroid2.ui.settings.TabSettings2Fragment;

public class DownloadListFragment extends TransferListFragment {

    public static DownloadListFragment newInstance() {
        Bundle args = new Bundle();
        DownloadListFragment fragment = new DownloadListFragment();
        fragment.setArguments(args);
        return fragment;
    }

    @Override
    public TransferAction getTransferAction() {
        return TransferAction.DOWNLOAD;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        initWorkerBusObserver();
    }

    private void initWorkerBusObserver() {
        BusHelper.getTransferProgressObserver().observe(getViewLifecycleOwner(), new Observer<Bundle>() {
            @Override
            public void onChanged(Bundle bundle) {
                doBusWork(bundle);
            }
        });
    }

    private void doBusWork(Bundle map) {
        String dataSource = map.getString(TransferWorker.KEY_DATA_SOURCE);
        String statusEvent = map.getString(TransferWorker.KEY_DATA_STATUS);
        String result = map.getString(TransferWorker.KEY_DATA_RESULT);
        String transferId = map.getString(TransferWorker.KEY_TRANSFER_ID);
        int transferCount = map.getInt(TransferWorker.KEY_TRANSFER_COUNT);
        SLogs.d("download list fragment, event: " + statusEvent + ", dataSource: " + dataSource + ", count: " + transferCount);

        if (!TextUtils.equals(TransferDataSource.DOWNLOAD.name(), dataSource)) {
            return;
        }

        TransferModel transferModel = getUploadModel(transferId);
        if (transferModel == null) {
            return;
        }

        if (TextUtils.equals(statusEvent, TransferEvent.EVENT_SCANNING)) {

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_SCAN_FINISH)) {

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_IN_TRANSFER)) {

            notifyProgressById(transferModel, statusEvent);
        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_TRANSFER_FAILED)) {

            SLogs.d(DownloadListFragment.class, transferModel.toString());
            notifyProgressById(transferModel, statusEvent);

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_TRANSFER_SUCCESS)) {

            notifyProgressById(transferModel, statusEvent);
        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_TRANSFER_FINISH)) {
            loadData();
        }

    }

//    @Override
//    public void deleteSelectedItems(List<FileTransferEntity> list) {
//        showDeleteConfirmDialog(list);
//    }

//    private void showDeleteConfirmDialog(List<FileTransferEntity> list) {
//        if (CollectionUtils.isEmpty(list)) {
//            return;
//        }
//
//        MaterialAlertDialogBuilder builder = new MaterialAlertDialogBuilder(requireContext());
//        builder.setTitle(R.string.delete_records);
//
//        String deleteFile = getString(R.string.delete_local_file_sametime);
//        CharSequence[] sequences = new CharSequence[1];
//        sequences[0] = deleteFile;
//        boolean[] booleans = new boolean[1];
//        booleans[0] = true;
//        builder.setMultiChoiceItems(sequences, booleans, new DialogInterface.OnMultiChoiceClickListener() {
//            @Override
//            public void onClick(DialogInterface dialog, int which, boolean isChecked) {
//                booleans[which] = isChecked;
//            }
//        });
//
//        builder.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
//            @Override
//            public void onClick(DialogInterface dialog, int which) {
//                doDeleteSelectedItem(list, booleans[0]);
//                dialog.dismiss();
//            }
//        });
//
//        builder.setNegativeButton(R.string.cancel, (dialog, which) -> dialog.dismiss());
//        builder.show();
//    }

//    private void doDeleteSelectedItem(List<FileTransferEntity> list, boolean isDeleteLocalFile) {
//        getViewModel().getShowLoadingDialogLiveData().setValue(true);
//
//        BackgroundJobManagerImpl.getInstance().cancelDownloadWorker();
//
//        getViewModel().removeSpecialDownloadListTask(list, isDeleteLocalFile, new Consumer<Boolean>() {
//            @Override
//            public void accept(Boolean aBoolean) {
//
//                BackgroundJobManagerImpl.getInstance().startDownloadChainWorker();
//
//                //You never know which item a user will select, so we need to remove them one by one, and then resort.
//                for (FileTransferEntity fileTransferEntity : list) {
//                    removeSpecialEntity(fileTransferEntity.uid);
//                }
//
//                getViewModel().getShowLoadingDialogLiveData().setValue(false);
//
//                ToastUtils.showLong(R.string.deleted);
//            }
//        });
//    }

}

==> com.seafile.seadroid2_185_src.tar.gz: com.seafile.seadroid2_185_src.tar.gz/app/src/main/java/com/seafile/seadroid2/ui/transfer_list/DownloadListFragment.java <==
package com.seafile.seadroid2.ui.transfer_list;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;

import com.seafile.seadroid2.bus.BusHelper;
import com.seafile.seadroid2.enums.TransferAction;
import com.seafile.seadroid2.enums.TransferDataSource;
import com.seafile.seadroid2.framework.worker.queue.TransferModel;
import com.seafile.seadroid2.framework.util.SLogs;
import com.seafile.seadroid2.framework.worker.TransferEvent;
import com.seafile.seadroid2.framework.worker.TransferWorker;
import com.seafile.seadroid2.ui.settings.TabSettings2Fragment;

public class DownloadListFragment extends TransferListFragment {
    private final String TAG = "DownloadListFragment";

    public static DownloadListFragment newInstance() {
        Bundle args = new Bundle();
        DownloadListFragment fragment = new DownloadListFragment();
        fragment.setArguments(args);
        return fragment;
    }

    @Override
    public TransferAction getTransferAction() {
        return TransferAction.DOWNLOAD;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        initWorkerBusObserver();
    }

    private void initWorkerBusObserver() {
        BusHelper.getTransferProgressObserver().observe(getViewLifecycleOwner(), new Observer<Bundle>() {
            @Override
            public void onChanged(Bundle bundle) {
                doBusWork(bundle);
            }
        });
    }

    private void doBusWork(Bundle map) {
        String dataSource = map.getString(TransferWorker.KEY_DATA_SOURCE);
        String statusEvent = map.getString(TransferWorker.KEY_DATA_STATUS);
        String result = map.getString(TransferWorker.KEY_DATA_RESULT);
        String transferId = map.getString(TransferWorker.KEY_TRANSFER_ID);
        int transferCount = map.getInt(TransferWorker.KEY_TRANSFER_COUNT);
        SLogs.d(TAG, "on event: " + statusEvent + ", dataSource: " + dataSource + ", count: " + transferCount);

        if (!TextUtils.equals(TransferDataSource.DOWNLOAD.name(), dataSource)) {
            return;
        }

        TransferModel transferModel = getUploadModel(transferId);
        if (transferModel == null) {
            return;
        }

        if (TextUtils.equals(statusEvent, TransferEvent.EVENT_SCANNING)) {

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_SCAN_FINISH)) {

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_IN_TRANSFER)) {

            notifyProgressById(transferModel, statusEvent);
        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_TRANSFER_FAILED)) {

            SLogs.d(TAG, transferModel.toString());
            notifyProgressById(transferModel, statusEvent);

        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_FILE_TRANSFER_SUCCESS)) {

            notifyProgressById(transferModel, statusEvent);
        } else if (TextUtils.equals(statusEvent, TransferEvent.EVENT_TRANSFER_FINISH)) {
            loadData();
        }

    }
}
